@@ -311,7 +311,7 @@ class MaemoReactor(object):
         text = pygame.transform.rotate(text, 90)
         self.screen.blit(text, (w-190,  h-5-text.get_height()))
         text = pygame.transform.rotate(text, 180)
-        self.screen.blit(text, (w/2+textSize, 5))
+        self.screen.blit(text, (w/2+9, 5))
     
     def drawText(self, text, center, width, orientation=None,
                  color=None, size=None):
